#![deny(missing_docs)]

//! # Game Skunk Advance
//! Game development library modelled after an imaginary console
//!
//! ## Specs
//! - Resolution: 304x176 (19x11 tiles)
//! - Colors: 256 (indexed out of a possible 24-bit)
//! - Tilesize: 16x16 (or 8x8 for half-tiles)
//! - Tileset: 65536 tiles, indexed via 0xYYXX
//! - Sprites: 256 of size 16x16 (pondering allowing larger sprites)
//! - Tilemaps: 4 of size 1024x1024, scrollable
//!
//! ## Features not yet implemented
//! - Tilemap effects
//!   - Rotation? Scaling?
//!   - Mosaic?
//!   - Mode7?
//! - Sprite Effects
//!   - Rotation? Scaling?
//!   - Mosaic?
//! - Sound (no samples)
//!   - Synth
//!   - Speech
//! - Savegames
//! - Helpers
//!   - Gamepad text keyboard input
//!   - Menus

mod buttons;
mod gsa;
mod gsa_render_to_screen;
mod rgb;
mod run;
mod sprite;
mod tilemap;
mod tileset;

pub use crate::buttons::*;
pub use crate::gsa::*;
pub use crate::rgb::*;
pub use crate::run::run;
pub use crate::sprite::*;
pub use crate::tilemap::*;

/// Amount of sprites in [Gsa::sprites]
pub const MAX_SPRITES: usize = 0xff;

/// Screen Width in pixels
pub const SCREEN_WIDTH: usize = 304;

/// Screen Height in pixels
pub const SCREEN_HEIGHT: usize = 176;

/// X and y dimensions of maps in [Gsa::maps]
pub const TILEMAP_MAX_SIZE: usize = 1024;

/// Width and height (in tiles) of tileset
pub const TILESET_SIZE: usize = 0x100;

/// Width and height of a tile
pub const TILE_SIZE: usize = 16;

/// Width and height of a tile in half-tile mode
pub const HALF_TILE_SIZE: usize = 8;

/// Amount of tile maps in [Gsa::maps]
pub const MAX_TILEMAPS: usize = 4;
